@@ -50,6 +50,7 @@ urlpatterns = [
     path('camera/create/', views.CameraCreate.as_view(), name='camera-create'),
     path('camera/<int:id_owner>/update',
          views.CameraUpdate.as_view(), name='camera-update'),
+    path('camera/<int:id_owner>/sell', views.CameraSell.as_view(), name='camera-sell'),
 
     path('cameramodel/', views.CameraModelList.as_view(), name='cameramodel-list'),
     path('cameramodel/<slug:slug>', views.CameraModelDetail.as_view(),
@@ -114,6 +115,7 @@ urlpatterns = [
     path('lens/create/', views.LensCreate.as_view(), name='lens-create'),
     path('lens/<int:id_owner>/update',
          views.LensUpdate.as_view(), name='lens-update'),
+    path('lens/<int:id_owner>/sell', views.LensSell.as_view(), name='lens-sell'),
 
     path('lensmodel/', views.LensModelList.as_view(), name='lensmodel-list'),
     path('lensmodel/<slug:slug>', views.LensModelDetail.as_view(),
